@@ -1,5 +1,5 @@
 from argparse import ArgumentParser
-from .dgx import create_app, delete_app
+from .dgx import create_app, delete_app, my_dir
 
 parser = ArgumentParser(description='Dealergeek Generator API Express', usage='DGX', )
 
@@ -17,6 +17,13 @@ parser.add_argument(
     required=False,
     help="Create a new api",
 )
+parser.add_argument(
+    "-m",
+    "--mdir",
+    default=None,
+    required=False,
+    help="current directory",
+)
 
 
 def main():
@@ -28,6 +35,8 @@ def main():
         create_app(args.create)
     elif args.delete:
         delete_app(args.delete)
+    elif args.mdir:
+        my_dir()
     else:
         parser.print_help()
 
