@@ -1,5 +1,6 @@
-from os import makedirs, path, listdir, symlink, system
+from os import makedirs, path, listdir, system, getcwd
 from werkzeug.utils import secure_filename
+from platform import platform
 import shutil
 
 
@@ -17,15 +18,21 @@ def create_virtual_env(name: str, rootProject: str, rootApi: str):
     """
     Crea entorno virtual e instala las dependencias
     """
-    rootApi = rootApi.replace(rootProject + '/', './')  # quita la carpeta raiz
-    print("cd ", rootProject)
+    exe_cmd = """
+    python3 -m venv {0}-venv;
+    source {0}-venv/bin/activate;
+    """.format(name)
+    if platform() == 'Windows':
+        exe_cmd = """
+        python -m venv {0}-venv;
+        /{0}/Scripts/activate;
+        """.format(name)
     system("""
-        cd {1};
-        python3 -m venv {0}-venv;
-        source {0}-venv/bin/activate;
+        cd {0};
+        {1}
         pip install --upgrade pip;
         pip install -r {2}/requirements.txt;
-    """.format(name, rootProject, rootApi))
+    """.format(rootProject, exe_cmd, rootApi))
 
 
 def delete_app(napp: str):
@@ -40,6 +47,10 @@ def delete_app(napp: str):
         print("you need to specify the api name 🤬")
 
 
+def my_dir():
+    print(getcwd())
+
+
 def create_app(napp: str):
     """
     Crea app
@@ -49,7 +60,7 @@ def create_app(napp: str):
         acode = input('app code 👉: ').strip()
         port = input('app port 👉: ').strip() or '5000'
         napp = secure_filename(napp).lower().replace('-api', '')
-        rootProject = napp + '-project'  # carpeta de proyecto
+        rootProject = path.join(getcwd(), napp + '-project')  # carpeta de proyecto
         rootPath = path.join(rootProject, napp + '-api')  # carpeta del api
         # crea carpetas
         for dname in ('', 'resources', '__temp__'):
